import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;

/**
  Represents a Song from the iTunes music store.
  
  @author Tom Austin
 */
public class Song
{
   //Properties of a song, taken from the XML search results
   private Map<String,String> properties;
   
   //Unique ID to identify the song, currently based on 'songId'
   // in Apple's results.
   private String ID;
   
   /**
      Constructor
    */
   public Song()
   {
      properties = new HashMap<String,String>();
   }
   
   /**
      Get a property for a song.
    */
   public String get(String key)
   {
      return properties.get(key);
   }
   
   /**
      Set a property for a song.
    */
   public void put(String key, String val) 
   {
      if (key.equals("songId")) ID=val;
      properties.put(key, val);
   }
   
   /**
      Returns the ID of the song.
    */
   public String getID()
   {
      return ID;
   }
   
   /**
      Used to calculate the file name of the song
      or its preview.  Path information is not included.
    */
   public String getFileName()
   {
      String artist = getWithDefault("artistName","").replaceAll("[ /]","_");
      String album = getWithDefault("playlistName","").replaceAll("[ /] ","_");
      String songName = getWithDefault("songName","").replaceAll("[ /]","_");
      
      return artist + "--" + album + "--" + songName + ".m4p";
   }
   
   /**
      Downloads preview to the specified directory and returns
      the file name and location.
    */
   public String downloadPreview(String prevDir){
      String outputFileName = null;
      try {
          URL previewUrl = new URL(properties.get("previewURL"));
          InputStream in = previewUrl.openStream();
          
          outputFileName = prevDir + "/" + getFileName();
          FileOutputStream out = new FileOutputStream(outputFileName);
          int b;
          while ((b=in.read()) != -1) {
              out.write(b);
          }
          in.close();
          out.close();
      }
      catch (Exception e){
          e.printStackTrace();
      }
      
      return outputFileName;
   }
   
   /**
      Returns the entry for this song for easy display
      
      @see java.lang.Object#toString()
    */
   @Override
   public String toString(){
      String artist = getWithDefault("artistName","");
      String album = getWithDefault("playlistName","");
      String songName = getWithDefault("songName","");
      
      return "  * ID=" + ID + " - "
            + songName + " by '" + artist + "' in the album '" + album + "'";
   }
   
   private String getWithDefault(String key, String defaultVal) {
      return properties.containsKey(key) ? properties.get(key) : defaultVal;
   }
}
